// ******************************************
// * $Id$
// *
// *   submitHTTP()
// *
// * Verstuur gegevens via HTTP naar een webservice
// * die de gegevens verder kan verwerken.
// *
// ******************************************
function submitHTTP( p_connect
                   , p_textstream
                   , p_bedrijfadres
                   )
{
    //
    // Verstuur de HTTP aanvraag
    //
    Log2File(2, "*> submitHTTP");

    var params = p_bedrijfadres;
    params.headers = { };

    // Patch voor CSU -> KPMG (Axxerion) koppeling
    if (p_bedrijfadres.encoding == 1) // multipart/form-data
    {
       boundary = "eWmWdiyWZVsqRAlEjgwicQsLnvXBJAVw"; // random genoeg, als het maar niet voorkomt in de data
       params.headers["Content-Type"] =  "multipart/form-data; boundary=" + boundary;

       var oStream = new ActiveXObject("ADODB.Stream");
       oStream.charset = "utf-8";
       oStream.Open();
       oStream.Type = 2; // adTypeText
       oStream.WriteText( "--" + boundary);
       oStream.WriteText('\r\nContent-Disposition: form-data; name="soapfile"; filename="facilitor.xml"');
       oStream.WriteText( "\r\nContent-Type: text/xml; charset=utf-8" );
       oStream.WriteText( "\r\n\r\n" );
       oStream.WriteText( p_textstream.ReadText() );
       oStream.WriteText( "\r\n--" + boundary + "--\r\n");
       oStream.Position = 0; //
       params.data = stream2text(oStream); // Zonder de stream2text krijg ik een ongewenste BOM ervoor
                                           // Ik snap niet waarom ik die bij p_textstream niet krijg
       LogStream2File(2, "HTTPrequest", params.data);
    }
    else // Gewoon plain
    {
       params.headers["Content-Type"] = "text/xml; charset=utf-8";
       params.data = p_textstream;
       LogString2File(2, "HTTPrequest", params.data);
    }
    var XMLhttp = doHTTP(p_connect.CurrentAddress, params);
    // Bij status buiten de 200 range is er al een exception geweest
    Log2File(3, "SOAP response = " + XMLhttp.responseText);

    Log2File(1, "XMLhttp.status: " + XMLhttp.status);
    Log2File(3, "HTTP response = " + XMLhttp.responseText);

    Log2File(2, "*< submitHTTP");

    return XMLhttp.responseText;
}
